#!/bin/bash
set -x
git submodule init
git submodule update --remote
./create-mapping.py -c rcm-metadata/product_ids/ -j rcm-metadata/cdn/product-certs.json -d RHEL -o RHEL/channel-cert-mapping.txt
./sanity-check.py RHEL 2>&1 | grep unused | cut -d' ' -f1 | xargs -I\{\} git rm RHEL/\{\}
